@@ -1,6 +1,7 @@
 __author__ = 'sibirrer'
 
 import numpy as np
+from scipy.interpolate import interp1d
 import lenstronomy.GalKin.velocity_util as vel_util
 from lenstronomy.GalKin.cosmo import Cosmo
 from lenstronomy.GalKin.anisotropy import Anisotropy
@@ -28,12 +29,20 @@ class AnalyticKinematics(Anisotropy):
     distances
 
     """
-    def __init__(self, kwargs_cosmo):
+    def __init__(self, kwargs_cosmo, interpol_grid_num=100, log_integration=False, max_integrate=100,
+                 min_integrate=0.001):
         """
 
-        :param kwargs_cosmo:
+        :param kwargs_cosmo: keyword argument with angular diameter distances
         """
 
+        self._interp_grid_num = interpol_grid_num
+        self._log_int = log_integration
+        self._max_integrate = max_integrate  # maximal integration (and interpolation) in units of arcsecs
+        self._min_integrate = min_integrate  # min integration (and interpolation) in units of arcsecs
+        self._max_interpolate = max_integrate  # we chose to set the interpolation range to the integration range
+        self._min_interpolate = min_integrate  # we chose to set the interpolation range to the integration range
+
         self._cosmo = Cosmo(**kwargs_cosmo)
         self._spp = SPP()
         #GalkinObservation.__init__(self, kwargs_psf=kwargs_psf, kwargs_aperture=kwargs_aperture)
@@ -70,7 +79,7 @@ class AnalyticKinematics(Anisotropy):
         :return: projected velocity dispersion
         """
         beta = self.beta_r(r, **{'r_ani': r_ani})
-        return (1 - beta * R**2/r**2) * self._sigma_r2(r, a, gamma, rho0_r0_gamma, r_ani)
+        return (1 - beta * R**2/r**2) * self._sigma_r2_interp(r, a, gamma, rho0_r0_gamma, r_ani)
 
     def sigma_s2(self, r, R, kwargs_mass, kwargs_light, kwargs_anisotropy):
         """
@@ -133,6 +142,26 @@ class AnalyticKinematics(Anisotropy):
         fac = r_ani**2/a**2 * hyp1 / ((2+gamma) * (r/a + 1)**(2+gamma)) + hyp2 / (gamma*(r/a)**gamma)
         return prefac1 * prefac2 * fac * (const.arcsec * self._cosmo.dd * const.Mpc) ** 2
 
+    def _sigma_r2_interp(self, r, a, gamma, rho0_r0_gamma, r_ani):
+        """
+
+        :param r:
+        :param a:
+        :param gamma:
+        :param rho0_r0_gamma:
+        :param r_ani:
+        :return:
+        """
+        if not hasattr(self, '_interp_sigma_r2'):
+            min_log = np.log10(self._min_integrate)
+            max_log = np.log10(self._max_integrate)
+            r_array = np.logspace(min_log, max_log, self._interp_grid_num)
+            I_R_sigma2_array = []
+            for r_i in r_array:
+                I_R_sigma2_array.append(self._sigma_r2(r_i, a, gamma, rho0_r0_gamma, r_ani))
+            self._interp_sigma_r2 = interp1d(np.log(r_array), np.array(I_R_sigma2_array), fill_value="extrapolate")
+        return self._interp_sigma_r2(np.log(r))
+
     def grav_potential(self, r, kwargs_mass):
         """
         Gravitational potential in SI units
@@ -155,4 +184,5 @@ class AnalyticKinematics(Anisotropy):
 
         :return:
         """
-        pass
+        if hasattr(self, '_interp_sigma_r2'):
+            del self._interp_sigma_r2
