@@ -68,12 +68,12 @@ class TNFW(LensProfileBase):
         x = np.maximum(x, self._s)
         if isinstance(x, np.ndarray):
             nfwvals = np.zeros_like(x)
-            inds1 = np.where((x < 1) & (x > 0))
+            inds1 = np.where(x < 1)
             inds2 = np.where(x > 1)
-            inds3 = np.where(x == 0)
+            inds3 = np.where(x == 1)
             nfwvals[inds1] = (1 - x[inds1] ** 2) ** -.5 * np.arctanh((1 - x[inds1] ** 2) ** .5)
             nfwvals[inds2] = (x[inds2] ** 2 - 1) ** -.5 * np.arctan((x[inds2] ** 2 - 1) ** .5)
-            #nfwvals[inds3] = 0
+            nfwvals[inds3] = 1
             return nfwvals
 
         elif isinstance(x, float) or isinstance(x, int):
@@ -88,6 +88,18 @@ class TNFW(LensProfileBase):
 
     def derivatives(self, x, y, Rs=None, alpha_Rs=None, r_trunc=None, center_x=0, center_y=0):
 
+        """
+        returns df/dx and df/dy of the function (integral of TNFW), which are the deflection angles
+
+        :param x: angular position (normally in units of arc seconds)
+        :param y: angular position (normally in units of arc seconds)
+        :param Rs: turn over point in the slope of the NFW profile in angular unit
+        :param alpha_Rs: deflection (angular units) at projected Rs
+        :param r_trunc: truncation radius (angular units)
+        :param center_x: center of halo (in angular units)
+        :param center_y: center of halo (in angular units)
+        :return: deflection angle in x, deflection angle in y
+        """
         rho0_input = self._alpha2rho0(alpha_Rs=alpha_Rs, Rs=Rs)
         #if Rs < 0.0000001:
         #    Rs = 0.0000001
@@ -100,11 +112,19 @@ class TNFW(LensProfileBase):
 
     def hessian(self, x, y, Rs, alpha_Rs, r_trunc, center_x=0, center_y=0):
 
-        #raise Exception('Hessian for truncated nfw profile not yet implemented.')
+        """
+        returns d^2f/dx^2, d^2f/dy^2, d^2f/dxdy of the TNFW potential f
 
+        :param x: angular position (normally in units of arc seconds)
+        :param y: angular position (normally in units of arc seconds)
+        :param Rs: turn over point in the slope of the NFW profile in angular unit
+        :param alpha_Rs: deflection (angular units) at projected Rs
+        :param r_trunc: truncation radius (angular units)
+        :param center_x: center of halo (in angular units)
+        :param center_y: center of halo (in angular units)
+        :return: Hessian matrix of function d^2f/dx^2, d^f/dy^2, d^2/dxdy
         """
-        returns Hessian matrix of function d^2f/dx^2, d^f/dy^2, d^2/dxdy
-        """
+
         rho0_input = self._alpha2rho0(alpha_Rs=alpha_Rs, Rs=Rs)
         #if Rs < 0.0001:
         #    Rs = 0.0001
