@@ -120,7 +120,7 @@ class Sampler(object):
         return result, [chi2_list, pos_list, vel_list]
 
     def mcmc_emcee(self, n_walkers, n_run, n_burn, mean_start, sigma_start, mpi=False, progress=False, threadCount=1,
-                   initpos=None):
+                   initpos=None, backup_filename=None, start_from_backup=False):
         """
         Run MCMC with emcee.
         For details, please have a look at the documentation of the emcee packager.
@@ -141,30 +141,51 @@ class Sampler(object):
         :type progress: bool
         :param threadCount: number of threats in multi-processing (not applicable for MPI)
         :type threadCount: integer
-        :param initpos: inital walker position to start sampling (optional)
+        :param initpos: initial walker position to start sampling (optional)
         :type initpos: numpy array of size num param x num walkser
+        :param backup_filename: name of the HDF5 file where sampling state is saved (through emcee backend engine)
+        :type backup_filename: string
+        :param start_from_backup: if True, start from the state saved in `backup_filename`.
+         Otherwise, create a new backup file with name `backup_filename` (any already existing file is overwritten!).
+        :type start_from_backup: bool
         :return: samples, ln likelihood value of samples
         :rtype: numpy 2d array, numpy 1d array
         """
         num_param, _ = self.chain.param.num_param()
         if initpos is None:
-            initpos = sampling_util.sample_ball(mean_start, sigma_start, n_walkers)
-
-        time_start = time.time()
+            initpos = sampling_util.sample_ball(mean_start, sigma_start, n_walkers, dist='normal')
 
         pool = choose_pool(mpi=mpi, processes=threadCount, use_dill=True)
 
-        sampler = emcee.EnsembleSampler(n_walkers, num_param, self.chain.logL,
-                                        pool=pool)
+        if backup_filename is not None:
+            backend = emcee.backends.HDFBackend(backup_filename, name="lenstronomy_mcmc_emcee")
+            if pool.is_master():
+                print("Warning: All samples (including burn-in) will be saved in backup file '{}'.".format(backup_filename))
+            if start_from_backup:
+                initpos = None
+                n_run_eff = n_run
+            else:
+                n_run_eff = n_burn + n_run
+                backend.reset(n_walkers, num_param)
+                if pool.is_master():
+                    print("Warning: backup file '{}' has been reset!".format(backup_filename))
+        else:
+            backend = None
+            n_run_eff = n_burn + n_run
 
-        sampler.run_mcmc(initpos, n_burn + n_run, progress=progress)
+        time_start = time.time()
+
+        sampler = emcee.EnsembleSampler(n_walkers, num_param, self.chain.logL,
+                                        pool=pool, backend=backend)
+
+        sampler.run_mcmc(initpos, n_run_eff, progress=progress)
         flat_samples = sampler.get_chain(discard=n_burn, thin=1, flat=True)
         dist = sampler.get_log_prob(flat=True, discard=n_burn, thin=1)
         if pool.is_master():
             print('Computing the MCMC...')
             print('Number of walkers = ', n_walkers)
             print('Burn-in iterations: ', n_burn)
-            print('Sampling iterations:', n_run)
+            print('Sampling iterations (in current run):', n_run_eff)
             time_end = time.time()
             print(time_end - time_start, 'time taken for MCMC sampling')
         return flat_samples, dist
