@@ -53,7 +53,7 @@ class TestLikelihoodModule(object):
         self.kwargs_ps = [{'ra_source': 0.55, 'dec_source': 0.02,
                            'source_amp': 1.}]  # quasar point source position in the source plane and intrinsic brightness
         self.kwargs_cosmo = {'D_dt': 1000}
-        kwargs_numerics = {'supersampling_factor': 1, 'supersampling_convolution': False, 'compute_mode': 'gaussian'}
+        kwargs_numerics = {'supersampling_factor': 1, 'supersampling_convolution': False}
         lens_model_class, source_model_class, lens_light_model_class, point_source_class, extinction_class = class_creator.create_class_instances(**kwargs_model)
         imageModel = ImageModel(data_class, psf_class, lens_model_class, source_model_class,
                                 lens_light_model_class, point_source_class, extinction_class, kwargs_numerics=kwargs_numerics)
